==> netrw-0.99.1.tar.bz2: netrw-0.99.1/src/checksum.h <==
/* $Id: checksum.h,v 1.3 2002/10/13 22:37:15 jirka Exp $ */

/*
 * netrw tools
 * Copyright (C) 2002 Jiri Denemark
 *
 * This file is part of netrw.
 *
 * netrw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef CHECKSUM_H
#define CHECKSUM_H

#include "proto_types.h"


/* protocol parameters */
#define PAR_STR_CHECKSUM  "checksum"

#define CHECKSUM_NONE   (-1)

#if USE_CHECKSUM_MHASH
#define CHECKSUMS_LIST  "md5", "sha1", "sha256", "rmd160"
#define CHECKSUMS_STR   "md5 sha1 sha156 rmd160"
#define CHECKSUM_MD5    ( 0)
#define CHECKSUM_SHA1   ( 1)
#define CHECKSUM_SHA256 ( 2)
#define CHECKSUM_RMD160 ( 3)

#elif USE_CHECKSUM_OPENSSL
#define CHECKSUMS_LIST  "md5", "sha1", "rmd160"
#define CHECKSUMS_STR   "md5 sha1 rmd160"
#define CHECKSUM_MD5    ( 0)
#define CHECKSUM_SHA1   ( 1)
#define CHECKSUM_RMD160 ( 2)

#elif USE_CHECKSUM_BUILT_IN
#define CHECKSUMS_LIST  "md5"
#define CHECKSUMS_STR   "md5"
#define CHECKSUM_MD5    ( 0)

#else
#error "Unknown checksum algorithm library"
#endif

static char *CHECKSUMS[] = { CHECKSUMS_LIST };
#define CHECKSUMS_CNT (sizeof(CHECKSUMS) / sizeof(char *))


/* option processing */
#define OPTION_c
#define CHECKSUM_OPT "c::"
#define CHECKSUM_USAGE \
    "  -c [algorithm]   check the whole transmission with the specified\n"  \
    "                   checksum algorithm. For checksum generation it\n"   \
    "                   is sufficient to use this option only once (with\n" \
    "                   either netread or netwrite).\n"                     \
    "                   Supported algorithms (the first is default):\n"     \
    "                       " CHECKSUMS_STR "\n"
#define CHECKSUM_CASE \
    case 'c':           /* checksum */                                      \
        if (udp)                                                            \
            usage(argv[0]);                                                 \
        params.checksum = 0;                                                \
        if (optarg) {                                                       \
            int index;                                                      \
            for (index = 0; index < CHECKSUMS_CNT; index++) {               \
                if (strcmp(optarg, CHECKSUMS[index]) == 0) {                \
                    params.checksum = index;                                \
                    break;                                                  \
                }                                                           \
            }                                                               \
        }                                                                   \
        break;


/*
 * checksum_init()
 *
 * initialize checksum data structures according to params->checksum
 *
 * return value:
 *      none
 *
 * side effects:
 *      static structure ctx is affected
 */
extern void checksum_init(const struct proto_params *params);

/*
 * checksum_process(buffer, len)
 *
 * process the specified buffer and update the checksum
 *
 * return value:
 *      none
 *
 * side effects:
 *      static structure ctx is affected
 */
extern void checksum_process(const void *buffer, const unsigned int len);

/*
 * checksum_finish()
 *
 * finalize checksum data structures
 *
 * return value:
 *      the computed checksum
 *
 * side effects:
 *      static structure ctx is affected
 *      static string checksum is fill in with the resulting checksum
 */
extern char *checksum_finish(void);

/*
 * checksum_exchange()
 *
 * send the computed checksum through the control connection and receives
 * the checksum computed by the remote party
 *
 * return value:
 *      remotly computed checksum
 *      NULL on failure
 *
 * side effects:
 *      sets static string remote_sum
 */
char *checksum_exchange(void);

/*
 * checksum_validate()
 *
 * compare the computed checksum with the one computed by the remote party
 *
 * return values:
 *      FN_SUCCESS ... ok
 *      FN_FAILURE ... checksums differ
 *
 * side effects:
 *      none
 */
extern int checksum_validate(void);

#endif

==> netrw-0.99.2.tar.bz2: netrw-0.99.2/src/checksum.h <==
/* $Id: checksum.h,v 1.6 2002/10/14 08:18:22 jirka Exp $ */

/*
 * netrw tools
 * Copyright (C) 2002 Jiri Denemark
 *
 * This file is part of netrw.
 *
 * netrw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef CHECKSUM_H
#define CHECKSUM_H

#include "proto_types.h"


/* protocol parameters */
#define PAR_STR_CHECKSUM  "checksum"

#define CHECKSUM_NONE   (-1)

#if USE_CHECKSUM_MHASH
#define CHECKSUMS_LIST  "md5", "sha1", "sha256", "rmd160", "tiger", "gost"
#define CHECKSUMS_STR   "md5 sha1 sha256 rmd160 tiger gost"
#define CHECKSUM_MD5    ( 0)
#define CHECKSUM_SHA1   ( 1)
#define CHECKSUM_SHA256 ( 2)
#define CHECKSUM_RMD160 ( 3)
#define CHECKSUM_TIGER  ( 4)
#define CHECKSUM_GOST   ( 5)

#elif USE_CHECKSUM_OPENSSL
#define CHECKSUMS_LIST  "md5", "sha1", "rmd160"
#define CHECKSUMS_STR   "md5 sha1 rmd160"
#define CHECKSUM_MD5    ( 0)
#define CHECKSUM_SHA1   ( 1)
#define CHECKSUM_RMD160 ( 2)

#elif USE_CHECKSUM_BUILT_IN
#define CHECKSUMS_LIST  "md5"
#define CHECKSUMS_STR   "md5"
#define CHECKSUM_MD5    ( 0)

#else
#error "Unknown checksum algorithm library"
#endif

static char *CHECKSUMS[] = { CHECKSUMS_LIST };
#define CHECKSUMS_CNT (sizeof(CHECKSUMS) / sizeof(char *))


/* option processing */
#define OPTION_c
#define CHECKSUM_OPT "c::"
#define CHECKSUM_USAGE \
    "  -c [algorithm]   check the whole transmission with the specified\n"  \
    "                   checksum algorithm. For checksum generation it\n"   \
    "                   is sufficient to use this option only once (with\n" \
    "                   either netread or netwrite).\n"                     \
    "                   Supported algorithms (the first is default):\n"     \
    "                       " CHECKSUMS_STR "\n"
#define CHECKSUM_CASE \
    case 'c':           /* checksum */                                      \
        if (udp)                                                            \
            usage(argv[0]);                                                 \
        params.checksum = 0;                                                \
        if (optarg) {                                                       \
            int index;                                                      \
            for (index = 0; index < CHECKSUMS_CNT; index++) {               \
                if (strcmp(optarg, CHECKSUMS[index]) == 0) {                \
                    params.checksum = index;                                \
                    break;                                                  \
                }                                                           \
            }                                                               \
        }                                                                   \
        break;


/*
 * checksum_init()
 *
 * initialize checksum data structures according to params->checksum
 *
 * return value:
 *      none
 *
 * side effects:
 *      static structure ctx is affected
 */
extern void checksum_init(const struct proto_params *params);

/*
 * checksum_process(buffer, len)
 *
 * process the specified buffer and update the checksum
 *
 * return value:
 *      none
 *
 * side effects:
 *      static structure ctx is affected
 */
extern void checksum_process(const void *buffer, const unsigned int len);

/*
 * checksum_finish()
 *
 * finalize checksum data structures
 *
 * return value:
 *      the computed checksum
 *
 * side effects:
 *      static structure ctx is affected
 *      static string checksum is fill in with the resulting checksum
 */
extern char *checksum_finish(void);

/*
 * checksum_exchange()
 *
 * send the computed checksum through the control connection and receives
 * the checksum computed by the remote party
 *
 * return value:
 *      remotly computed checksum
 *      NULL on failure
 *
 * side effects:
 *      sets static string remote_sum
 */
char *checksum_exchange(void);

/*
 * checksum_validate()
 *
 * compare the computed checksum with the one computed by the remote party
 *
 * return values:
 *      FN_SUCCESS ... ok
 *      FN_FAILURE ... checksums differ
 *
 * side effects:
 *      none
 */
extern int checksum_validate(void);

#endif
